@@ -8,7 +8,7 @@
 from typing import Any
 
 
-def _prepare_class_name(bases: list[type], modifier: Any) -> str:
+def prepare_class_name(bases: list[type], modifier: Any) -> str:
     def split_by_brackets(class_string: str) -> list[str]:
         parts = class_string.split("[")
         return parts
@@ -36,3 +36,9 @@ def _prepare_class_name(bases: list[type], modifier: Any) -> str:
             is_next_char_upper = True
 
     return result
+
+
+def _prepare_class_name(bases: list[type], modifier: Any) -> str:
+    import warnings
+    warnings.warn("'_prepare_class_name' is deprecated, use 'prepare_class_name' instead", DeprecationWarning)
+    return prepare_class_name(bases, modifier)
